==> client-sdk-react-2.1.0.tgz: package/src/store/aiFeatures/aiFeatureSlice.ts <==
import { createSelector, createSlice, PayloadAction } from '@reduxjs/toolkit'
import { AIFeatureModel, AIFeaturesModel, AIFeaturesStatus } from './models'
import { AIFeature, AIFeatureType, AIResult } from '@zocks-communications/client-sdk-js'
import { RootState } from '../../app/store'
import { ErrorResponse } from '../../components'

const initialState: AIFeaturesModel = {
  aiFeaturesStatus: AIFeaturesStatus.INITIAL,
  aiFeatures: {},
  errors: [],
}

export const aiFeatureSlice = createSlice({
  name: 'aiFeature',
  initialState,
  reducers: {
    initAIFeatures: (state, action: PayloadAction<AIFeature[]>) => {
      action.payload.forEach((aiFeature) => {
        state.aiFeatures[aiFeature.id] = { ...aiFeature, results: [] }
      })
      state.aiFeaturesStatus = AIFeaturesStatus.SUCCESS
    },
    initAIResults: (state, action: PayloadAction<AIResult[]>) => {
      action.payload.forEach((aiResult) => {
        if (state.aiFeatures[aiResult.aiFeatureId]) {
          state.aiFeatures[aiResult.aiFeatureId].results = [...action.payload]
        }
      })
      state.aiFeaturesStatus = AIFeaturesStatus.SUCCESS
    },
    setAIFeaturesStatus: (state, action: PayloadAction<AIFeaturesStatus>) => {
      state.aiFeaturesStatus = action.payload
    },
    clearAIFeatures: (state) => {
      state.aiFeatures = {}
      state.aiFeaturesStatus = AIFeaturesStatus.IDLE
    },
    setAIFeaturesError: (state, action: PayloadAction<ErrorResponse>) => {
      state.aiFeaturesStatus = AIFeaturesStatus.ERROR
      state.errors = action.payload.errors
    },
    aiResultReceived: (state, action: PayloadAction<AIResult>) => {
      const aiFeature = state.aiFeatures[action.payload.aiFeatureId]
      switch (true) {
        case action.payload.result.type === AIFeatureType.TOPIC_DETECTION:
          handleTopicDetectionAIResultReceived(aiFeature, action.payload)
          return
        default:
          aiFeature.results.push(action.payload)
          return
      }
    },
  },
})

const handleTopicDetectionAIResultReceived = (aiFeature: AIFeatureModel | null, aiResult: AIResult) => {
  if (aiFeature && aiFeature.config.topics.includes(aiResult.result.detectedTopic)) {
    aiFeature.results.push(aiResult)
  }
}

export const {
  initAIFeatures,
  initAIResults,
  setAIFeaturesError,
  setAIFeaturesStatus,
  clearAIFeatures,
  aiResultReceived,
} = aiFeatureSlice.actions
export const selectAIFeatures = createSelector(
  [(state) => state.aifeature.aiFeatures],
  (aiFeatures): AIFeatureModel[] => {
    return Object.values(aiFeatures)
  }
)
export const selectAIFeaturesStatus = (state: RootState): AIFeaturesStatus => state.aiFeature.aiFeaturesStatus
export default aiFeatureSlice.reducer

==> client-sdk-react-2.1.2.tgz: package/src/store/aiFeatures/aiFeatureSlice.ts <==
import { createSelector, createSlice, PayloadAction } from '@reduxjs/toolkit'
import { AIFeatureModel, AIFeaturesModel, AIFeaturesStatus } from './models'
import { AIFeature, AIFeatureType, AIResult } from '@zocks-communications/client-sdk-js'
import { RootState } from '../../app/store'
import { ErrorResponse } from '../../components'

const initialState: AIFeaturesModel = {
  aiFeaturesStatus: AIFeaturesStatus.INITIAL,
  aiFeatures: {},
  errors: [],
}

export const aiFeatureSlice = createSlice({
  name: 'aiFeature',
  initialState,
  reducers: {
    initAIFeatures: (state, action: PayloadAction<AIFeature[]>) => {
      action.payload.forEach((aiFeature) => {
        state.aiFeatures[aiFeature.id] = { ...aiFeature, results: [] }
      })
      state.aiFeaturesStatus = AIFeaturesStatus.SUCCESS
    },
    initAIResults: (state, action: PayloadAction<AIResult[]>) => {
      action.payload.forEach((aiResult) => {
        if (state.aiFeatures[aiResult.aiFeatureId]) {
          state.aiFeatures[aiResult.aiFeatureId].results = [...action.payload]
        }
      })
      state.aiFeaturesStatus = AIFeaturesStatus.SUCCESS
    },
    setAIFeaturesStatus: (state, action: PayloadAction<AIFeaturesStatus>) => {
      state.aiFeaturesStatus = action.payload
    },
    clearAIFeatures: (state) => {
      state.aiFeatures = {}
      state.aiFeaturesStatus = AIFeaturesStatus.IDLE
    },
    setAIFeaturesError: (state, action: PayloadAction<ErrorResponse>) => {
      state.aiFeaturesStatus = AIFeaturesStatus.ERROR
      state.errors = action.payload.errors
    },
    aiResultReceived: (state, action: PayloadAction<AIResult>) => {
      const aiFeature = state.aiFeatures[action.payload.aiFeatureId]
      switch (true) {
        case action.payload.result.type === AIFeatureType.TOPIC_DETECTION:
          handleTopicDetectionAIResultReceived(aiFeature, action.payload)
          return
        default:
          aiFeature.results.push(action.payload)
          return
      }
    },
  },
})

const handleTopicDetectionAIResultReceived = (aiFeature: AIFeatureModel | null, aiResult: AIResult) => {
  if (aiFeature && aiFeature.config.topics.includes(aiResult.result.detectedTopic)) {
    aiFeature.results.push(aiResult)
  }
}

export const {
  initAIFeatures,
  initAIResults,
  setAIFeaturesError,
  setAIFeaturesStatus,
  clearAIFeatures,
  aiResultReceived,
} = aiFeatureSlice.actions
export const selectAIFeatures = createSelector(
  [(state) => state.aiFeature.aiFeatures],
  (aiFeatures): AIFeatureModel[] => {
    return Object.values(aiFeatures)
  }
)
export const selectAIFeaturesStatus = (state: RootState): AIFeaturesStatus => state.aiFeature.aiFeaturesStatus
export default aiFeatureSlice.reducer
